@@ -1,5 +1,5 @@
 import numpy as np
-from variable import Variable
+from .variable import Variable
 
 #defining the trigonometric functions
 def sin(var):
@@ -44,7 +44,7 @@ def arccos(var):
     if isinstance(var, Variable):
         return Variable(arccos(var.val), (-1/np.sqrt(1 - (var.val)**2)) * var.der)
     else:
-        return np.arcsin(var)
+        return np.arccos(var)
 
 def arctan(var):
     """Adapts the arctan function to work with dual numbers"""
